@@ -1,5 +1,3 @@
-from __future__ import absolute_import, unicode_literals
-
 from django.apps import apps
 from django.core.exceptions import ImproperlyConfigured
 
@@ -9,11 +7,11 @@ from compressor.conf import settings
 if apps.is_installed("django.contrib.staticfiles"):
     from django.contrib.staticfiles import finders  # noqa
 
-    if ("compressor.finders.CompressorFinder"
-            not in settings.STATICFILES_FINDERS):
+    if "compressor.finders.CompressorFinder" not in settings.STATICFILES_FINDERS:
         raise ImproperlyConfigured(
             "When using Django Compressor together with staticfiles, "
             "please add 'compressor.finders.CompressorFinder' to the "
-            "STATICFILES_FINDERS setting.")
+            "STATICFILES_FINDERS setting."
+        )
 else:
     finders = None  # noqa
